@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2017 The OpenMx Project
+#   Copyright 2007-2018 The OpenMx Project
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -34,7 +34,8 @@ setClass(Class = "MxFlatModel",
 		datasets = "list",
 		constMatrices = "list",
 		freeMatrices = "list",
-		parameters = "list"
+		parameters = "list",
+		unsafe = "logical"
 	),
 	contains = "MxModel")
 	
@@ -254,7 +255,7 @@ checkVariablesHelper <- function(matrix, startVals, freeVars,
 						omxQuotes(simplifyName(loc[[1]], modelname)), 
 						"at location", 
 						rowColToString(loc[[2]], loc[[3]]),
-						"If you want to randomly select one of these values, call",
+						"Equate the values manually, give them distinct labels, or free the parameters and call",
 						"model <- omxAssignFirstParameters(model)",
 						"before running again."), call. = FALSE)
 				} else {
