@@ -1,5 +1,5 @@
 #
-#   Copyright 2007-2017 The OpenMx Project
+#   Copyright 2007-2018 The OpenMx Project
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -187,34 +187,6 @@ mxThreshold <- function(vars, nThresh=NA, free=FALSE, values=NA, # normalQuantil
 	
 }
 
-generateThresholdColumns <- function(flatModel, model, labelsData, covarianceColumnNames, dataName, threshName) {
-	covarianceLength <- length(covarianceColumnNames)
-	thresholdColumns <- replicate(covarianceLength, as.integer(NA))
-	thresholdLevels <- replicate(covarianceLength, as.integer(NA))
-	if (single.na(threshName)) {
-		return(list(thresholdColumns, thresholdLevels))
-	}
-
-	tuple <- evaluateMxObject(threshName, flatModel, labelsData, new.env(parent = emptyenv()))
-	thresholds <- tuple[[1]]
-
-	thresholdColumnNames <- dimnames(thresholds)[[2]]
-	datasource <- flatModel@datasets[[dataName]]@observed
-	for(i in 1:length(thresholdColumnNames)) {
-		oneThresholdName <- thresholdColumnNames[[i]]
-		if(flatModel@datasets[[dataName]]@type != 'acov'){
-			numThresholds <- length(levels(datasource[, oneThresholdName])) - 1
-		} else {
-			numThresholds <- sum(!is.na(flatModel@datasets[[dataName]]@thresholds[, oneThresholdName]))
-			# Note: this requires NA to be the indicator for an ignorable threshold
-		}
-		columnIndex <- match(oneThresholdName, covarianceColumnNames)
-		thresholdColumns[[columnIndex]] <- as.integer(i - 1)
-		thresholdLevels[[columnIndex]] <- as.integer(numThresholds)
-	}
-	return(list(thresholdColumns, thresholdLevels))
-}
-
 generateDataThresholdColumns <- function(covarianceColumnNames, thresholdsMatrix) {
 	covarianceLength <- length(covarianceColumnNames)
 	thresholdColumns <- replicate(covarianceLength, as.integer(NA))
@@ -232,7 +204,7 @@ generateDataThresholdColumns <- function(covarianceColumnNames, thresholdsMatrix
 }
 
 verifyThresholds <- function(flatModel, model, labelsData, dataName, covNames, threshName) {
-	if (single.na(threshName)) {
+	if (single.na(threshName) || flatModel@unsafe) {
 		return()
 	}
 	
